Crate recs

Crate recs 

Statics

DEBUGGING
Debugging should be set while initializing the lib. If not defined, the default is disabled.
PROGNAME
This value is set by set_prog. It is used for logging, creating paths, and other functions. To handle its creation or modification, use set_prog() to avoid wrapping.

Functions

decrypt_raw
Decrypts raw data.
encrypt_raw
Encrypts raw data.
house_keeping
Performs house keeping tasks cleans the .rand files from raw encrypt requests re-indexs the system array to ensure valid versions and signatures.
initialize
Initialize checks the progname and debugging values and ensures the lib is ready to function
ping
Checks if a file exists.
remove
Removes a file.
retrieve
Retrieves a file by decrypting it.
set_debug
Changes some mandatory logging functions and enables longer outputs in logs
set_prog
This function handles setting the PROGNAME variable.
store
Inserts a file by encrypting and storing it.
update_map
Updates the map with new data.