Component

Trait Component 

pub trait Component: Any { }
Marker trait for types which can be used as components.

Component is automatically implemented for all eligible types by the provided impl, so you don’t have to worry about this. Hooray!

Implementors

Source

impl<T: Any> Component for T